#!/bin/sh
###############################################################################
#
# Licensed Materials-Property of IBM, 5733-TA1
# (C)Copyright IBM Corp 1997
# (C)Copyright Tivoli Systems, an IBM Co 1997
# All rights reserved
# US Government Users Restricted Rights
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
#
# Licensed Materials-Property of IBM, 5697-EAS
# (C)Copyright IBM Corp 1998
# (C)Copyright Tivoli Systems, an IBM Co 1998
# All rights reserved
# US Government Users Restricted Rights
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
#
# Licensed Materials-Property of IBM, 5697-EAS
# (C)Copyright IBM Corp 1999
# (C)Copyright Tivoli Systems, an IBM Co 1999
# All rights reserved
# US Government Users Restricted Rights:
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
#
# Licensed Materials-Property of IBM, 5697-EAS
# (C)Copyright IBM Corp 2000
# (C)Copyright Tivoli Systems, an IBM Co 2000
# All rights reserved
# US Government Users Restricted Rights:
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
#
# Licensed Materials-Property of IBM, 5697-EAS
# (C)Copyright IBM Corp 2001
# (C)Copyright Tivoli Systems, an IBM Co 2001
# All rights reserved
# US Government Users Restricted Rights
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
#
###############################################################################

###############################################################################
#
# BAROC   : tec
# VERSION : 3.9
# OWNER   : Blair Drenner
#           Tivoli Enterprise Console
#           Correlation & Automation
#           IBM Corporation
#
# DESCRITPION
#
#   This script will install the .rls file into the
#   user-specified rule base for patches only.  Typically, we don't
#   want to copy over the .baroc or .pro files as the customer
#   may have modified these files. 
#
# PARAMETERS
#  rule_base_name - the name of the rulebase to install the Availability
#                   outage classes, rules and fact files into.
# USAGE
#
#  install.sh <rule_base_name>
#
#############################################################################
#used for the return code so the script will stop on first error
rc=0

#-------------------------
# Check to make sure the Tivoli environment is sourced
#------------------------
if [ "$TEMP" = "" ]; then
      echo "install.sh must be run after the Tivoli environment is sourced."
      exit
fi
TEMPDIR=`echo $TEMP | sed 's,\\\\,/,g'`
#--------------------
# The Usage Statement
#--------------------
usage() {
   echo "Usage:  install.sh rule_base_name"
}


#-------------------------
# Check Usage
#------------------------
if [ "$1" = "" ]; then
      usage
      exit
fi

#-----------------------------
# Copy over the files that are updated in the patch and change the file permissions on the
# the files because the wrb command reqiures that they have write permission.
#-----------------------------

echo Copying install files to: $TEMPDIR

if [ $rc -eq 0 ] ; then
  cp warehouse.rls "$TEMPDIR"
  rc=$?
fi

if [ $rc -eq 0 ] ; then
  chmod a+w "$TEMPDIR"/warehouse.rls
  rc=$?
fi

#check to see if the rule base exists
if [ $rc -eq 0 ] ; then
  wrb -lsrb $1
  rc=$?
fi

#--------------------------
# Remove the ruleset before we import again (for updates only)
#--------------------------
 if [ $rc -eq 0 ] ; then
   wrb -deltgtrule warehouse EventServer     $1
 rc=$?
 fi

 if [ $rc -eq 0 ] ; then
   wrb -delrbrule warehouse $1
 rc=$?
 fi


#---------------------------
# Import new rules
#---------------------------
if [ $rc -eq 0 ] ; then
  wrb -imprbrule "$TEMPDIR"/warehouse.rls    $1
  rc=$?
fi

if [ $rc -eq 0 ] ; then
  wrb -imptgtrule warehouse EventServer     $1
  rc=$?
fi

if [ $rc -eq 0 ] ; then
  echo "Installation Complete"
else
  echo "Errors During Installation"
fi

exit $rc
